@@ -160,8 +160,6 @@ def init(ctx, provider_token, email, size, region, force, namespace, environment
 	if not os.path.exists(content_dir):
 		os.mkdir(content_dir)
 
-	primary_url = util.primary_url()
-
 	# Automatically enable premium if it's been set up
 	premium_license = util.get_sail_default('premium')
 	premium_email = util.get_sail_default('email')
@@ -172,6 +170,14 @@ def init(ctx, provider_token, email, size, region, force, namespace, environment
 			util.item('Could not initialize Premium')
 
 	util.heading('Initialization successful')
+	_success(passwords['wp'])
+
+def _success(wp_password):
+	config = util.config()
+	primary_url = util.primary_url()
+	email = config['email']
+	hostname = config['hostname']
+
 	util.item('The ship has sailed!')
 	click.echo()
 
@@ -183,12 +189,11 @@ def init(ctx, provider_token, email, size, region, force, namespace, environment
 	label = util.label('Login:')
 	click.echo(f'{label} {primary_url}/wp-login.php')
 
-	label = util.label('Username:')
+	label = util.label('E-mail:')
 	click.echo(f'{label} {email}')
 
 	label = util.label('Password:')
-	password = passwords['wp']
-	click.echo(f'{label} {password}')
+	click.echo(f'{label} {wp_password}')
 
 	click.echo()
 
@@ -474,6 +479,7 @@ def _install(passwords):
 
 	util.item('Downloading and installing WordPress')
 	wp = 'sudo -u www-data wp --path=%s/releases/1337 ' % remote_path
+	admin_user = config['email'].split('@')[0]
 
 	c.run(wp + 'core download')
 	c.run(wp + util.join([
@@ -486,7 +492,7 @@ def _install(passwords):
 		'core', 'install',
 		'--url=%s' % util.primary_url(),
 		'--title=Sailed',
-		'--admin_user=%s' % config['email'],
+		'--admin_user=%s' % admin_user,
 		'--admin_password=%s' % passwords['wp'],
 		'--admin_email=%s' % config['email'],
 		'--skip-email'
