@@ -18,10 +18,12 @@ _request = Mock()
 _rmtree = Mock()
 _droplet = Mock()
 _sshkey = Mock()
+_delete_dns_records = Mock()
 
 @patch('sail.util.find_root', _find_root)
 @patch('sail.util.config', _util_config)
 @patch('sail.util.request', _request)
+@patch('sail.domains._delete_dns_records', _delete_dns_records)
 @patch('shutil.rmtree', _rmtree)
 @patch('digitalocean.Droplet', _droplet)
 @patch('digitalocean.SSHKey', _sshkey)
